==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/37/37346229aa4b086d355a5646585d4967.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/PluginBundle/Event/PluginIntegrationAuthRedirectEvent.php */
class __TwigTemplate_e1c3916358bcc26afc912659ec4d9ab0 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\PluginBundle\\Event;

use Mautic\\PluginBundle\\Integration\\UnifiedIntegrationInterface;

class PluginIntegrationAuthRedirectEvent extends AbstractPluginIntegrationEvent
{
    /**
     * @param string \$authUrl
     */
    public function __construct(
        UnifiedIntegrationInterface \$integration,
        private \$authUrl
    ) {
        \$this->integration = \$integration;
    }

    /**
     * @return string
     */
    public function getAuthUrl()
    {
        return \$this->authUrl;
    }

    /**
     * @param string \$authUrl
     */
    public function setAuthUrl(\$authUrl): void
    {
        \$this->authUrl = \$authUrl;

        \$this->stopPropagation();
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/PluginBundle/Event/PluginIntegrationAuthRedirectEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/PluginBundle/Event/PluginIntegrationAuthRedirectEvent.php", "/var/www/html/mauticGIT-Test/app/bundles/PluginBundle/Event/PluginIntegrationAuthRedirectEvent.php");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/37/37346229aa4b086d355a5646585d4967.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/PluginBundle/Event/PluginIntegrationAuthRedirectEvent.php */
class __TwigTemplate_e1c3916358bcc26afc912659ec4d9ab0 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\PluginBundle\\Event;

use Mautic\\PluginBundle\\Integration\\UnifiedIntegrationInterface;

class PluginIntegrationAuthRedirectEvent extends AbstractPluginIntegrationEvent
{
    /**
     * @param string \$authUrl
     */
    public function __construct(
        UnifiedIntegrationInterface \$integration,
        private \$authUrl
    ) {
        \$this->integration = \$integration;
    }

    /**
     * @return string
     */
    public function getAuthUrl()
    {
        return \$this->authUrl;
    }

    /**
     * @param string \$authUrl
     */
    public function setAuthUrl(\$authUrl): void
    {
        \$this->authUrl = \$authUrl;

        \$this->stopPropagation();
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/PluginBundle/Event/PluginIntegrationAuthRedirectEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/PluginBundle/Event/PluginIntegrationAuthRedirectEvent.php", "/var/www/html/production-demo/app/bundles/PluginBundle/Event/PluginIntegrationAuthRedirectEvent.php");
    }
}
